.docker
.editorconfig
.env
.gitattributes
.github
.gitignore
.php-cs-fixer.dist.php
README.md
SECURITY.md
bin
codeception.yml
composer.enterprise.json
composer.json
composer.lock
config
docker-compose.yaml
gpl-3.0.txt
public
src
templates
tests
translations
var
vendor
.htaccess